Struct Serial
Source pub struct Serial {
initialized: AtomicBool,
base_addr: u16,
}
x86_64 UART serial port implementing _Serial; do not write() before init().
I/O base address for this COM port (e.g., 0x03F8 for COM1).
Create a new (uninitialized) serial port instance for the given COM port.
Program the UART hardware and mark the port ready; Err if already initialized.
Write all bytes of string to the port, blocking until each is accepted.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.